@@ -15,23 +15,8 @@ from dash._utils import (
     stringify_id,
     format_tag
 )
-
-from .api import (
-    analysis_list_view,
-    analysis_detail_view,
-    analysis_run_list_view,
-    analysis_run_detail_view,
-    analysis_export_create_view,
-    analysis_export_detail_view,
-    analysis_send_list_view,
-    compute_view,
-    oap_get_users
-)
 from .utilities import is_authenticated
-import logging
-logger = logging.getLogger(__name__)
-
-
+BASE_API_URL = os.getenv('DATA_API_BASE_URL', '')
 
 _app_entry = """
     <main id="AnalyticsAppsUI-container">
@@ -45,18 +30,14 @@ class OAPDash(dash.Dash):
     static_files = {
         'css': [
             'main.wrapper.css'
-        ],
-        'js': [
-            'main.wrapper.js'
         ]
     }
 
     def __init__(self, **kwargs):
         self.route = kwargs.pop('route')
-        self.func_compute = kwargs.pop('func_compute')
-
-        self.in_store_id = "_oap_data_in_" + self.route
-        self.out_store_id = "_oap_data_out_" + self.route
+        app_id = os.getenv('APP_ID')
+        self.in_store_id = "_oap_data_in_" + app_id
+        self.out_store_id = "_oap_data_out_" + app_id
 
         route_prefix = f'/{self.route}' if self.route else ''
         # assume this is not set by user
@@ -71,37 +52,23 @@ class OAPDash(dash.Dash):
         """
         super(OAPDash, self).init_app(app)
 
-        assets_folder = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)), 'analysis-wrapper'
-        )
 
         # register static files for wrapper
         self.server.register_blueprint(
             flask.Blueprint(
                 'analytics_sdk_assets',
                 self.config.name,
-                static_folder=assets_folder,
                 static_url_path="{}{}".format(
                     self.config.routes_pathname_prefix,
                     'wrapper-static',
+                    )
                 )
             )
-        )
 
         # register manifest files
         self._add_url("opsramp-analytics-utils/<string:file_name>", self.serve_resource)
         self._add_url("asset-manifest.json", self.serve_manifest)
 
-        # register api endpoints
-        self._add_url("analyses/", analysis_list_view, ['GET', 'POST'])
-        self._add_url("analyses/<string:id>/", analysis_detail_view, ['PUT', 'GET', 'DELETE'])
-        self._add_url("analysis-runs/", analysis_run_list_view, ['GET'])
-        self._add_url("analysis-runs/<string:id>/", analysis_run_detail_view, ['GET', 'DELETE'])
-        self._add_url("analysis-sends/", partial(analysis_send_list_view, self.func_compute), ['POST', 'DELETE'])
-        self._add_url("analysis-exports/", analysis_export_create_view, ['POST'])
-        self._add_url("analysis-exports/<string:id>/", analysis_export_detail_view, ['GET', 'DELETE'])
-        self._add_url("compute", partial(compute_view, self.func_compute), ['POST'])
-        self._add_url("oap/users", oap_get_users, ['GET'])
 
     def _index(self, *args, **kwargs):  # pylint: disable=unused-argument
         scripts = self._generate_scripts_html()
@@ -144,13 +111,16 @@ class OAPDash(dash.Dash):
 
         return index
 
+
     def index(self, *args, **kwargs):  # pylint: disable=unused-argument
         if is_authenticated():
-            logging.error(f'oap_dash file  is_authentication if block')
             resp = self._index(args, kwargs)
             return resp
         else:
-            return flask.Response('Not authorized', status=401)
+            # return flask.Response('Not authorized', status=401)
+            redirect_url = BASE_API_URL + f'/tenancy/web/login?cb=/loginResponse.do'
+            return flask.redirect(redirect_url, code=302)
+
 
     def serve_manifest(self):
         return {
@@ -219,12 +189,6 @@ class OAPDash(dash.Dash):
         # external js files
         external_links = self.config.external_scripts
 
-        # oap js files
-        if os.getenv("INCLUDE_WRAPPER") == "true":
-            for file_path in self.static_files['js']:
-                _body = pkgutil.get_data('analytics_sdk', 'analysis-wrapper/'+file_path).decode("utf-8")
-                body += self.pre_process(_body, file_path, dev)
-
         # system js files
         mode = "dev" if self._dev_tools["props_check"] is True else "prod"
 
@@ -267,10 +231,7 @@ class OAPDash(dash.Dash):
             txt_body = txt_body.replace("JSON.parse(document.getElementById('_dash-config').textContent);", "oap_config;")  # in dev
             txt_body = txt_body.replace("JSON.parse(document.getElementById(\"_dash-config\").textContent);", "oap_config;")  # in live
             txt_body = txt_body.replace('react-entry-point', _report_content_entry_id_)
-        elif file_name == 'main.wrapper.js':
-            static_media_path = f'{self.config.requests_pathname_prefix.lstrip("/")}wrapper-static/media/'
-            txt_body = txt_body.replace('static/media/', static_media_path)
-
+        
         return txt_body + "\n"
 
     def get_component_ids(self, layout):
