@@ -93,7 +93,7 @@ class ExcelRenderer:
             difference = int(et - st)
             return difference
         
-        url = BASE_API_URL + f'/analytics/api/v3/tenants/{tenantId}/runs/{analysis_run}/summary'
+        url = BASE_API_URL + f'/reporting/api/v3/tenants/{tenantId}/runs/{analysis_run}/summary'
         api_proce_before_time = time.time()
         res = call_requests('GET', url)
         if res == None or not res.ok:
