@@ -421,7 +421,7 @@ def diff_sec(st, et):
 
 def update_status_url(analysisRunId, tenantId, genStime, genEtime, status=None):
 
-    url = BASE_API_URL + f'/analytics/api/v3/tenants/{tenantId}/runs/{analysisRunId}'
+    url = BASE_API_URL + f'/reporting/api/v3/tenants/{tenantId}/runs/{analysisRunId}'
     data={
             "status" : status,
             "runDurStartDate" : genStime,
@@ -439,7 +439,7 @@ def update_status_url(analysisRunId, tenantId, genStime, genEtime, status=None):
 
 def update_results_url(gen_start_time, analysisRunId, tenantId, json_result_url=None, gen_completed_time=None, excel_result_url=None, pdf_result_url=None, failure_reason=None, status=None):
 
-    url = BASE_API_URL + f'/analytics/api/v3/tenants/{tenantId}/runs/{analysisRunId}'
+    url = BASE_API_URL + f'/reporting/api/v3/tenants/{tenantId}/runs/{analysisRunId}'
     
     if storage_name == 'ceph':
         if excel_result_url is not None:
@@ -532,7 +532,7 @@ def init_mail(org_id, run_id):
     logger.info('Entered into init_mail method')
     try:
         # /tenants/{tenantId}/runs/{id}/sends
-        url = BASE_API_URL + f'/analytics/api/v3/tenants/{org_id}/runs/{run_id}/sends'
+        url = BASE_API_URL + f'/reporting/api/v3/tenants/{org_id}/runs/{run_id}/sends'
         data = {}
         t1 = int(time.time())
         res = call_post_requests(url , data=json.dumps(data), verify=False)
@@ -693,7 +693,7 @@ def get_post_opsql_count_results(url, data, type):
 
 
 def update_run_progress(tenant_id, run_id, percent, message):
-    url = BASE_API_URL + f'/analytics/api/v3/tenants/{tenant_id}/runs/{run_id}'
+    url = BASE_API_URL + f'/reporting/api/v3/tenants/{tenant_id}/runs/{run_id}'
     data = {
         "percent" : percent,
         "message" : message
